@@ -1,5 +1,5 @@
 package Debug::CodeBlock;
-use 5.006; use strict; use warnings; our $VERSION = '0.04';
+use 5.006; use strict; use warnings; our $VERSION = '1.00';
 use base 'Import::Export';
 use Data::Dumper qw//;
 our %EX = ( DEBUG => [qw/all/] );
@@ -23,7 +23,7 @@ Debug::CodeBlock - Add DEBUG codeblocks to your code.
 
 =head1 VERSION
 
-Version 0.04
+Version 1.00
 
 =cut
 
@@ -97,10 +97,6 @@ You can also look for information at:
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Debug-CodeBlock>
 
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/Debug-CodeBlock>
-
 =item * Search CPAN
 
 L<https://metacpan.org/release/Debug-CodeBlock>
